Estimates the edge weights or edge parameters of a model parameterized cliquewise by Huesler-Reiss distributions. For description of the model, please consult the Vignette "Introduction".
estimate(obj, ...)# S3 method for HRMtree
estimate(obj, Data, subsets, k_ratio, xx = NULL, ...)
# S3 method for HRMBG
estimate(obj, Data, subsets, k_ratio, xx = NULL, ...)
# S3 method for EKS
estimate(obj, Data, coord, k_ratio, ...)
# S3 method for MMEave
estimate(obj, Data, k_ratio, ...)
# S3 method for MLEave
estimate(obj, Data, k_ratio, ...)
An object of the same class as the argument obj where the slot $depParams are the estimates
of edge weights. For objects MME it returns the squared
values of the parameters.
object of on of the following classes MME, MLE1, MLE2, EKS, EKS_part, EngHitz, MME_ave, MLE_ave, HRMBG.
The classes MME, MLE1, MLE2, EKS, EKS_part, EngHitz are subclasses of class HRMtree,
hence if no other method is available, the method for HRMtree applies.
additional arguments
the dataset, it should have named columns.
object of class RootDepSet containing the roots and the respective subsets.
When obj is of class EngHitz the argument subsets should be a list of subsets,
not a RootDepSet object. When obj is of class EngHitz the union of all subsets should cover
the whole vertex set and also
every pair of subsets can have at most one node in common. See also Vignettes
"Code - Note 4" and "Estimation - Note 4".
a scalar the ratio of the number of upper order statistics to the number of observations
A vector of length the number of observed variables and named with the names of the nodes with
observed variables.
Default is NULL. For estimate.EKS_part it should be filled in. For the other methods
the value at default should be kept.
A matrix of evaluation points with number of columns equal to the number of nodes in the tree and
column names according to the
names of the nodes.
The matrix of evaluation points should not contain a positive coordinate for a variable which is unobserved.
For creation of coordinates based on tuples, triples, and adjacent nodes see classes
Coordinates, Tuples, Triples, Adjacent as well as method evalPoints
For an object of class EKS_part for a fixed subset all coordinates based on both tuples and triples
are taken.